==> qtjambi-location-debuginfo-linux-x64-6.5.3.jar: sources/QtJambiLocation/QPlaceSearchReply_shell.h <==
#ifndef QPLACESEARCHREPLY_SHELL_H
#define QPLACESEARCHREPLY_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtLocation/qplacesearchreply.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtLocation/qplacereply.h>
#include <QtLocation/qplacesearchrequest.h>
#include <QtLocation/qplacesearchresult.h>
#include <QtJambi/RegistryAPI>


class QPlaceSearchReply_shell : public QPlaceSearchReply, public QtJambiShellInterface
{
public:
    QPlaceSearchReply_shell(QObject* parent0 = nullptr);
    ~QPlaceSearchReply_shell() override;

    void abort() override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    QPlaceReply::Type type() const override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QPlaceSearchReply_access : public QPlaceSearchReply
{
    void __qt_setNextPageRequest_cref_QPlaceSearchRequest(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID next0);
    void __qt_setPreviousPageRequest_cref_QPlaceSearchRequest(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID previous0);
    void __qt_setRequest_cref_QPlaceSearchRequest(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID request0);
    void __qt_setResults_cref_QList(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject results0);
    jint __qt_type(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QPLACESEARCHREPLY_SHELL_H

==> qtjambi-location-debuginfo-linux-x64-6.5.5.jar: sources/QtJambiLocation/QPlaceSearchReply_shell.h <==
#ifndef QPLACESEARCHREPLY_SHELL_H
#define QPLACESEARCHREPLY_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtLocation/qplacesearchreply.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtLocation/qplacereply.h>
#include <QtLocation/qplacesearchrequest.h>
#include <QtLocation/qplacesearchresult.h>
#include <QtJambi/RegistryAPI>


class QPlaceSearchReply_shell : public QPlaceSearchReply, public QtJambiShellInterface
{
public:
    QPlaceSearchReply_shell(QObject* parent0 = nullptr);
    ~QPlaceSearchReply_shell() override;

    void abort() override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    QPlaceReply::Type type() const override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QPlaceSearchReply_access : public QPlaceSearchReply
{
    void __qt_setNextPageRequest_cref_QPlaceSearchRequest(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID next0);
    void __qt_setPreviousPageRequest_cref_QPlaceSearchRequest(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID previous0);
    void __qt_setRequest_cref_QPlaceSearchRequest(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID request0);
    void __qt_setResults_cref_QList(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject results0);
    jint __qt_type_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QPLACESEARCHREPLY_SHELL_H
